@@ -9,6 +9,7 @@ use egui_plot::{Corner, Legend, Line, Plot, PlotPoint, PlotPoints};
 use libamdgpu_top::{
     AMDGPU::{GpuMetrics, MetricsInfo, RasErrorCount},
     DevicePath,
+    GuiMode,
     PCI,
     stat::{FdInfoSortType, PerfCounter, Sensors},
 };
@@ -35,7 +36,7 @@ pub struct MyApp {
     pub no_pc: bool,
     pub pause: bool,
     pub full_fdinfo_list: bool,
-    pub tab_gui: bool,
+    pub gui_mode: GuiMode,
     pub main_tab: MainTab,
     pub info_tab: InfoTab,
 }
@@ -363,7 +364,7 @@ impl MyApp {
                     "GFX_SCLK",
                     // some AMD GPUs support DS (Deep Sleep) state
                     0,
-                    self.buf_data.device_info.max_gpu_clk,
+                    self.buf_data.device_info.max_od_gpu_clk.unwrap_or(self.buf_data.device_info.max_gpu_clk),
                     fl!("mhz"),
                 ),
                 (
@@ -372,7 +373,7 @@ impl MyApp {
                     "GFX_MCLK",
                     // some AMD GPUs support DS (Deep Sleep) state
                     0,
-                    self.buf_data.device_info.max_mem_clk,
+                    self.buf_data.device_info.max_od_mem_clk.unwrap_or(self.buf_data.device_info.max_mem_clk),
                     fl!("mhz"),
                 ),
                 (
@@ -396,7 +397,7 @@ impl MyApp {
                     sensors.average_power.as_ref().map(|power| power.value),
                     "Average Power",
                     0,
-                    if let Some(cap) = &sensors.power_cap { cap.current } else { 350 }, // "350 W" is not an exact value
+                    sensors.power_cap.as_ref().map(|cap| cap.current).unwrap_or(350), // "350 W" is not an exact value
                     fl!("w"),
                 ),
                 (
@@ -404,7 +405,7 @@ impl MyApp {
                     sensors.input_power.as_ref().map(|power| power.value),
                     "Input Power",
                     0,
-                    if let Some(cap) = &sensors.power_cap { cap.current } else { 350 }, // "350 W" is not an exact value
+                    sensors.power_cap.as_ref().map(|cap| cap.current).unwrap_or(350), // "350 W" is not an exact value
                     fl!("w"),
                 ),
                 (
@@ -746,11 +747,15 @@ impl MyApp {
     }
 
     pub fn egui_vclk_dclk_plot(&self, ui: &mut egui::Ui) {
-        let [vclk, dclk, vclk1, dclk1] = [
-            &self.buf_data.history.vclk,
-            &self.buf_data.history.dclk,
-            &self.buf_data.history.vclk1,
-            &self.buf_data.history.dclk1,
+        let [avg_vclk, avg_dclk, avg_vclk1, avg_dclk1, cur_vclk, cur_dclk, cur_vclk1, cur_dclk1] = [
+            &self.buf_data.history.avg_vclk,
+            &self.buf_data.history.avg_dclk,
+            &self.buf_data.history.avg_vclk1,
+            &self.buf_data.history.avg_dclk1,
+            &self.buf_data.history.cur_vclk,
+            &self.buf_data.history.cur_dclk,
+            &self.buf_data.history.cur_vclk1,
+            &self.buf_data.history.cur_dclk1,
         ].map(|history| history.iter().map(|(i, clk)| [i, clk as f64]).collect::<Vec<[f64; 2]>>());
         let label_fmt = |name: &str, val: &PlotPoint| {
             format!("{:.1}s : {name} {:.0} MHz", val.x, val.y)
@@ -767,10 +772,14 @@ impl MyApp {
             .legend(Legend::default().position(Corner::LeftTop))
             .show(ui, |plot_ui| {
                 for (clk, name) in [
-                    (vclk, "VCLK"),
-                    (dclk, "DCLK"),
-                    (vclk1, "VCLK1"),
-                    (dclk1, "DCLK1"),
+                    (avg_vclk, "VCLK (Avg.)"),
+                    (avg_dclk, "DCLK (Avg.)"),
+                    (avg_vclk1, "VCLK1 (Avg.)"),
+                    (avg_dclk1, "DCLK1 (Avg.)"),
+                    (cur_vclk, "VCLK (Cur.)"),
+                    (cur_dclk, "DCLK (Cur.)"),
+                    (cur_vclk1, "VCLK1 (Cur.)"),
+                    (cur_dclk1, "DCLK1 (Cur.)"),
                 ] {
                     if !clk.is_empty() {
                         plot_ui.line(Line::new(name, PlotPoints::new(clk)))
