@@ -20,6 +20,7 @@ impl AppTextView {
         for (name, val, unit) in [
             ("GFX_SCLK", sensors.sclk, "MHz"),
             ("GFX_MCLK", sensors.mclk, "MHz"),
+            ("FCLK", sensors.fclk_dpm.as_ref().map(|f| f.current_mhz), "MHz"),
             ("VDDNB", sensors.vddnb, "mV"),
             ("VDDGFX", sensors.vddgfx, "mV"),
         ] {
@@ -109,9 +110,11 @@ impl AppTextView {
             writeln!(self.text.buf, " PCI Power State: {power_state}")?;
         }
 
-        if let Some(power_profile) = &sensors.power_profile {
-            writeln!(self.text.buf, " Power Profile: {power_profile}")?;
-        }
+        sensors.print_all_cpu_core_cur_freq(
+            &mut self.text.buf,
+            " CPU Core freq (MHz)",
+            false,
+        )?;
 
         Ok(())
     }
