@@ -1,5 +1,8 @@
 use std::time::Duration;
 use std::path::PathBuf;
+
+use num_enum::{IntoPrimitive, TryFromPrimitive};
+
 pub use libdrm_amdgpu_sys::*;
 use libdrm_amdgpu_sys::AMDGPU::{
     CHIP_CLASS,
@@ -24,6 +27,20 @@ pub use drm_mode::*;
 mod ppfeaturemask;
 pub use ppfeaturemask::*;
 
+#[derive(Debug, Copy, Clone, Eq, PartialEq, IntoPrimitive, TryFromPrimitive)]
+#[repr(u8)]
+pub enum GuiMode {
+    Auto,
+    Single,
+    Tab,
+}
+
+impl GuiMode {
+    pub fn is_tab_mode(&self) -> bool {
+        *self == Self::Tab
+    }
+}
+
 #[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum GuiWgpuBackend {
     Gl,
@@ -39,7 +56,7 @@ pub struct UiArgs {
     pub is_dark_mode: Option<bool>, // TUI, GUI
     pub hide_fdinfo: bool, // TUI
     pub gui_wgpu_backend: GuiWgpuBackend, // GUI
-    pub tab_gui: bool, // GUI
+    pub gui_mode: GuiMode, // GUI
 }
 
 pub struct Sampling {
@@ -102,41 +119,6 @@ impl VramUsage {
     }
 }
 
-pub fn has_vcn(amdgpu_dev: &DeviceHandle) -> bool {
-    #[cfg(debug_assertions)]
-    {
-        if let Ok(s) = std::env::var("DBG_VCN") {
-            return s == "1";
-        }
-    }
-
-    amdgpu_dev.get_hw_ip_info(HW_IP_TYPE::VCN_DEC).is_ok()
-}
-
-pub fn has_vcn_unified(amdgpu_dev: &DeviceHandle) -> bool {
-    #[cfg(debug_assertions)]
-    {
-        if let Ok(s) = std::env::var("DBG_VCNU") {
-            return s == "1";
-        }
-    }
-
-    let Ok(ip) = amdgpu_dev.get_hw_ip_info(HW_IP_TYPE::VCN_ENC) else { return false };
-
-    4 <= ip.info.hw_ip_version_major
-}
-
-pub fn has_vpe(amdgpu_dev: &DeviceHandle) -> bool {
-    #[cfg(debug_assertions)]
-    {
-        if let Ok(s) = std::env::var("DBG_VPE") {
-            return s == "1";
-        }
-    }
-
-    amdgpu_dev.get_hw_ip_info(HW_IP_TYPE::VPE).is_ok()
-}
-
 pub fn get_hw_ip_info_list(
     amdgpu_dev: &DeviceHandle,
     chip_class: CHIP_CLASS,
