@@ -1,5 +1,6 @@
-// GRBM: Graphics Register Bus Management
-// ref: https://rocmdocs.amd.com/en/develop/understand/gpu_arch/mi200_performance_counters.html
+// GRBM: Graphics Register Bus Manager
+// ref: https://github.com/ROCm/ROCm/blob/rocm-7.1.1/docs/conceptual/gpu-arch/mi300-mi200-performance-counters.rst#graphics-register-bus-manager-counters
+// ref: https://www.kernel.org/doc/html/latest/gpu/amdgpu/amdgpu-glossary.html
 
 pub(crate) const GRBM_INDEX: &[(&str, usize)] = &[
     ("Graphics Pipe", 31),
@@ -32,7 +33,7 @@ pub(crate) const GFX10_GRBM_INDEX: &[(&str, usize)] = &[
 ];
 
 pub(crate) const GRBM2_INDEX: &[(&str, usize)] = &[
-    ("Ring List Controller", 24),
+    ("RunList Controller", 24),
     ("Texture Cache", 25),
     // ("Texture Cache Resident", 26),
     ("Command Processor -  Fetcher", 28),
@@ -41,7 +42,7 @@ pub(crate) const GRBM2_INDEX: &[(&str, usize)] = &[
 ];
 
 pub(crate) const GFX9_GRBM2_INDEX: &[(&str, usize)] = &[
-    ("Ring List Controller", 24),
+    ("RunList Controller", 24),
     ("Texture Cache", 25),
     // ("Texture Cache Resident", 26),
     ("Unified Translation Cache Level-2", 15), // UTCL2
@@ -53,7 +54,7 @@ pub(crate) const GFX9_GRBM2_INDEX: &[(&str, usize)] = &[
 ];
 
 pub(crate) const GFX10_GRBM2_INDEX: &[(&str, usize)] = &[
-    ("Ring List Controller", 24),
+    ("RunList Controller", 24),
     ("Texture Cache per Pipe", 25),
     ("Unified Translation Cache Level-2", 15), // UTCL2
     ("Efficiency Arbiter", 16), // EA
@@ -65,7 +66,7 @@ pub(crate) const GFX10_GRBM2_INDEX: &[(&str, usize)] = &[
 ];
 
 pub(crate) const GFX10_3_GRBM2_INDEX: &[(&str, usize)] = &[
-    ("Ring List Controller", 26),
+    ("RunList Controller", 26),
     ("Texture Cache per Pipe", 27),
     ("Unified Translation Cache Level-2", 15), // UTCL2
     ("Efficiency Arbiter", 16), // EA
@@ -77,7 +78,7 @@ pub(crate) const GFX10_3_GRBM2_INDEX: &[(&str, usize)] = &[
 ];
 
 pub(crate) const GFX12_GRBM2_INDEX: &[(&str, usize)] = &[
-    ("Ring List Controller", 26),
+    ("RunList Controller", 26),
     ("Texture Cache per Pipe", 27),
     ("Unified Translation Cache Level-2", 15), // UTCL2
     ("Efficiency Arbiter", 16), // EA
